"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.Package = void 0;
const fs_1 = require("fs");
const path_1 = require("path");
const resolve_1 = __importDefault(require("resolve"));
const File_1 = require("./File");
const getTypedName_1 = require("./utils/getTypedName");
class Package {
    cwd;
    opts;
    typesRoot;
    pkgRoot;
    importPrefix;
    rootPackage;
    packages;
    files;
    entryFile;
    constructor(opts) {
        this.opts = opts;
        this.cwd = fs_1.realpathSync(opts.cwd);
        this.rootPackage = opts.rootPackage || this;
        this.typesRoot = opts.typesRoot || path_1.join(this.cwd, 'types', opts.name);
        this.packages = {
            [this.opts.name]: true,
        };
        this.files = {};
        this.init();
    }
    addFile(file) {
        this.files[file] = true;
    }
    init() {
        const entryFile = this.getEntryFile();
        this.entryFile = entryFile;
        this.addFile(entryFile);
        new File_1.File({
            pkg: this,
            filePath: entryFile,
        });
    }
    getPkg() {
        let pkg = {};
        let pkgRoot = '';
        try {
            const pkgJSONPath = resolve_1.default.sync(`${this.opts.name}/package.json`, {
                basedir: this.cwd,
            });
            pkgRoot = path_1.dirname(pkgJSONPath);
            pkg = JSON.parse(fs_1.readFileSync(pkgJSONPath, 'utf-8'));
        }
        catch (_e) { }
        return {
            pkg,
            pkgRoot,
        };
    }
    getEntryFile() {
        const { pkg, pkgRoot } = this.getPkg();
        const types = pkg.types || pkg.typings;
        if (types) {
            this.pkgRoot = pkgRoot;
            if (types.endsWith('.d.ts') &&
                fs_1.statSync(path_1.join(pkgRoot, types)).isFile() &&
                fs_1.existsSync(path_1.join(pkgRoot, types))) {
                return types;
            }
            else if (fs_1.existsSync(path_1.join(pkgRoot, `${types}.d.ts`))) {
                return `${types}.d.ts`;
            }
            else if (fs_1.existsSync(path_1.join(pkgRoot, types, 'index.d.ts'))) {
                return path_1.join(types, 'index.d.ts');
            }
            else {
                throw new Error(`Package ${this.opts.name} 里声明了 types 为 ${pkg.types}，但实际不存在。`);
            }
        }
        else if (fs_1.existsSync(path_1.join(pkgRoot, 'index.d.ts'))) {
            this.pkgRoot = pkgRoot;
            return 'index.d.ts';
            // } else if (
            //   pkg.main &&
            //   existsSync(join(pkgRoot, getTypesFormMain({ main: pkg.main })))
            // ) {
            //   this.pkgRoot = pkgRoot;
            //   return getTypesFormMain({ main: pkg.main });
        }
        else {
            const typedName = getTypedName_1.getTypedName(this.opts.name);
            const typedPkgJSONPath = resolve_1.default.sync(`${typedName}/package.json`, {
                basedir: this.cwd,
            });
            const typedPkgRoot = path_1.dirname(typedPkgJSONPath);
            const typedPkg = JSON.parse(fs_1.readFileSync(typedPkgJSONPath, 'utf-8'));
            this.pkgRoot = typedPkgRoot;
            const types = typedPkg.types || typedPkg.typings;
            if (types && fs_1.existsSync(path_1.join(typedPkgRoot, types))) {
                return types;
            }
            else if (fs_1.existsSync(path_1.join(typedPkgRoot, 'index.d.ts'))) {
                return 'index.d.ts';
            }
            else {
                throw new Error(`找不到 ${typedName} 的入口文件。`);
            }
        }
    }
}
exports.Package = Package;
